## 🔧 Changes

### Remove Python 3.10 and 3.11 support

The minimum Python version is now 3.12. The CI test matrix now covers Python 3.12 and 3.13.

*By @mavam and @claude.*

## 🐞 Bug fixes

### Fix CLI linting issues

Fix linting issues in the CLI module.

*By @mavam.*
